@@ -46,6 +46,8 @@ TODO:
 import os, stat
 import pygame
 
+import resizing
+
 # 64MiB
 MAX_CACHE_DIR = 64 * (1024*1024)
 
@@ -137,8 +139,20 @@ class ImageOps(object):
                image,
                width,
                height,
-               rotate = False):
+               rotate = False,
+               exact_width = True,
+               exact_height = True,
+              ):
         """ resize the image.  Return the path of the resized image.
+
+        gallery:      gallery in which the image is kept.
+        image:        file name of the image.
+        width:        wanted width to resize to.
+        height:       wanted height to resize to.
+        exact_width:  keep the exact width we ask for.  Otherwise use one 
+                      based on the correct size from the heights aspect ratio.
+        exact_height: keep the exact hight we ask for.  Otherwise use one 
+                      based on the correct size from the widths aspect ratio.
         """
         width, height = int(width), int(height)
 
@@ -190,12 +204,25 @@ class ImageOps(object):
             raise NotImplementedError('rotate not implemented')
         else:
             surf = pygame.image.load(path)
+
+            # do we keep the aspect ratio or not?
+            if not exact_width or not exact_height:
+                sw, sh = surf.get_size()
+                if exact_width:
+                    size = resizing.resize_aspect(sw, sh, width)
+                else:
+                    size = resizing.resize_aspect(sw, sh, None, height)
+                awidth, aheight = size
+            else:
+                awidth, aheight = width, height
+
+            print (awidth, aheight)
             try:
                 transformed_surf = pygame.transform.smoothscale(surf, 
-                                                            (width, height))
+                                                            (awidth, aheight))
             except ValueError: 
                 transformed_surf = pygame.transform.scale(surf, 
-                                                            (width, height))
+                                                            (awidth, aheight))
 
         # TODO: save to a temporary file in the same directory, then move.
         pygame.image.save(transformed_surf, cached_fname)
